@@ -6,11 +6,13 @@ HTML::HiLiter - highlight words in an HTML document just like a felt-tip HiLiter
 
 =head1 VERSION
 
-0.11
+0.12
 
 =cut
 
 # TODO: would HTML::Tree be faster?
+# or even XML::LibXML since we assume libxml2 for swish-e?
+# perhaps experiment with both and toggle on the fly?
 
 
 package HTML::HiLiter;
@@ -20,7 +22,7 @@ use strict;
 use sigtrap qw(die normal-signals error-signals);
 
 use vars qw( 
-		$VERSION $BegChar $EndChar $WordChar $White_Space $HiTag 
+		$VERSION $BegChar $EndChar $WordChar $White_Space $HiTag $HiClass
 		$CSS_Class $hrefs $buffer $Debug $Delim $color $nocolor
 		$OC $CC %entity2char %codeunis %unicodes %char2entity $ISO_ext
 		@whitesp $SkipTag
@@ -40,7 +42,7 @@ unless ($@) {
 #$ticker = 0;
 
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 
 $OC = "\n<!--\n";
@@ -289,6 +291,8 @@ $White_Space 	= join('|', @whitesp);
 
 $HiTag 		= 'span';	# what tag to use to hilite
 
+$HiClass        = undef;        # what class to use (none by default)
+
 $CSS_Class 	= 'hilite';
 
 $buffer 	= '';		# init the buffer
@@ -459,6 +463,7 @@ sub _init
 				
 	
 	$self->{HiTag} 		||= $HiTag;
+	$self->{HiClass}	= $HiClass unless( defined $self->{HiClass} );
 	$self->{Colors} 	||= [ '#FFFF99', '#99FFFF', '#ffccff', '#ccccff' ];					
 	$self->{Links}		||= 0;		# off by default
 	
@@ -905,8 +910,8 @@ sub plaintext
 	{
 	
 	    my $re = $self->{Queries}->{$q}->[1] || warn "no re for $q\n", next Q;
-	    my $o = $self->{OTags}->{$q};
-	    my $c = $self->{CTags}->{$q};
+	    my $o = $self->{OTags}->{$q} || '';
+	    my $c = $self->{CTags}->{$q} || '';
 		
 		
 		#print $OC . "looking for $re in $text" . $CC;
@@ -1036,9 +1041,10 @@ sub hilite
 
 	my $tagless = $self->{dtext} || $html;	# if we didn't have dtext, we weren't using HTML::Parser
 	
-# if the html we have has no tags (entities okay), call plaintext() instead
-	if ( 	$tagless eq $html and
-		$tagless !~ m/[<>]/ and
+# if the html has no tags or entities, call plaintext() instead
+	if ( 
+        $tagless eq $html and
+		$tagless !~ m/[<>&]/ and
 		! $self->{noplain}
 		) {
 		return $self->plaintext( $html );
@@ -1240,8 +1246,16 @@ sub _make_styles_css
 			) unless $tagset =~ m/$CSS_Class$num/;
 			# only define it once
 			# but assign a definition to each query
-		my $s = "class='" . $CSS_Class.$num++ . "'";
-		$self->{OTags}->{$_} = "<$tag $s>";
+                my $s = '';
+                # use HiClass if we have it
+                if( defined $self->{HiClass} ) {
+                    # this allows for having an empty, but defined HiClass
+                    $s = "class='$self->{HiClass}'" if $self->{HiClass};
+                } else {
+		    $s = "class='" . $CSS_Class.$num++ . "'";
+                }
+
+		$self->{OTags}->{$_} = $s ? "<$tag $s>" : "<$tag>";
 		$self->{CTags}->{$_} = "</$tag>";	# this is always the same; should we bother?
 		$num = 0 if $num > $#colors;	# start over if we exceed
 						# total number of colors
@@ -1265,8 +1279,16 @@ sub _make_styles_inline
 	my $tag = $self->{HiTag};
 	for (@$queries) {
 		
-		my $s = "style='background:" . $colors[$num++] . "'";
-		$self->{OTags}->{$_} = "<$tag $s>";
+                my $s = '';
+                # if we are using HiClass
+                if( defined $self->{HiClass} ) {
+                    # this allows for having an empty, but defined HiClass
+		    $s = "class='$self->{HiClass}'" if( $self->{HiClass} );
+                # else, use the color
+                } else {
+		    $s = "style='background:" . $colors[$num++] . "'";
+                }
+		$self->{OTags}->{$_} = $s ? "<$tag $s>" : "<$tag>";
 		$self->{CTags}->{$_} = "</$tag>";	# this is always the same; should we bother?
 		$num = 0 if $num > $#colors;	# start over if we exceed
 						# total number of colors
@@ -1747,7 +1769,7 @@ sub prep_queries
 					my @stemmed = split //, $f;
 					my @char = split //, $w;
 					$f = '';	#reset
-					while ( $stemmed[0] eq $char[0] ) {
+					while ( @char && @stemmed && $stemmed[0] eq $char[0] ) {
 						$f .= shift @stemmed;
 						shift @char;
 					}
@@ -2117,6 +2139,11 @@ based on [^EndCharacters] plus some regexp niceties.
 
 The HTML tag to use to wrap highlighted words. Default: span
 
+=item HiClass
+
+The HTML class attribute used within the HiTag. If not specified, the class name
+will be auto generated by the Colors array.
+
 =item Colors
 
 A reference to an array of HTML colors.
